summaryrefslogtreecommitdiff
path: root/SRC
diff options
context:
space:
mode:
Diffstat (limited to 'SRC')
-rw-r--r--SRC/CMakeLists.txt16
-rw-r--r--SRC/Makefile8
-rw-r--r--SRC/chesv_aa.f (renamed from SRC/chesv_aasen.f)28
-rw-r--r--SRC/chetrf_aa.f (renamed from SRC/chetrf_aasen.f)24
-rw-r--r--SRC/chetrs_aa.f (renamed from SRC/chetrs_aasen.f)26
-rw-r--r--SRC/clahef_aa.f (renamed from SRC/clahef_aasen.f)24
-rw-r--r--SRC/dlasyf_aa.f (renamed from SRC/dlasyf_aasen.f)24
-rw-r--r--SRC/dsysv_aa.f (renamed from SRC/dsysv_aasen.f)26
-rw-r--r--SRC/dsytrf_aa.f (renamed from SRC/dsytrf_aasen.f)24
-rw-r--r--SRC/dsytrs_aa.f (renamed from SRC/dsytrs_aasen.f)26
-rw-r--r--SRC/slasyf_aa.f (renamed from SRC/slasyf_aasen.f)24
-rw-r--r--SRC/ssysv_aa.f (renamed from SRC/ssysv_aasen.f)24
-rw-r--r--SRC/ssytrf_aa.f (renamed from SRC/ssytrf_aasen.f)24
-rw-r--r--SRC/ssytrs_aa.f (renamed from SRC/ssytrs_aasen.f)26
-rw-r--r--SRC/zhesv_aa.f (renamed from SRC/zhesv_aasen.f)28
-rw-r--r--SRC/zhetrf_aa.f (renamed from SRC/zhetrf_aasen.f)24
-rw-r--r--SRC/zhetrs_aa.f (renamed from SRC/zhetrs_aasen.f)26
-rw-r--r--SRC/zlahef_aa.f (renamed from SRC/zlahef_aasen.f)24
18 files changed, 213 insertions, 213 deletions
diff --git a/SRC/CMakeLists.txt b/SRC/CMakeLists.txt
index 0ceea60b..9c76592c 100644
--- a/SRC/CMakeLists.txt
+++ b/SRC/CMakeLists.txt
@@ -114,7 +114,7 @@ set(SLASRC
slaqtr.f slar1v.f slar2v.f ilaslr.f ilaslc.f
slarf.f slarfb.f slarfg.f slarfgp.f slarft.f slarfx.f slargv.f
slarrv.f slartv.f
- slarz.f slarzb.f slarzt.f slaswp.f slasy2.f slasyf.f slasyf_rook.f slasyf_aasen.f
+ slarz.f slarzb.f slarzt.f slaswp.f slasy2.f slasyf.f slasyf_rook.f slasyf_aa.f
slatbs.f slatdf.f slatps.f slatrd.f slatrs.f slatrz.f
slauu2.f slauum.f sopgtr.f sopmtr.f sorg2l.f sorg2r.f
sorgbr.f sorghr.f sorgl2.f sorglq.f sorgql.f sorgqr.f sorgr2.f
@@ -135,7 +135,7 @@ set(SLASRC
ssygst.f ssygv.f ssygvd.f ssygvx.f ssyrfs.f ssysv.f ssysvx.f
ssytd2.f ssytf2.f ssytrd.f ssytrf.f ssytri.f ssytri2.f ssytri2x.f
ssyswapr.f ssytrs.f ssytrs2.f ssyconv.f
- ssysv_aasen.f ssytrf_aasen.f ssytrs_aasen.f
+ ssysv_aa.f ssytrf_aa.f ssytrs_aa.f
ssytf2_rook.f ssytrf_rook.f ssytrs_rook.f
ssytri_rook.f ssycon_rook.f ssysv_rook.f
stbcon.f
@@ -189,7 +189,7 @@ set(CLASRC
chetf2.f chetrd.f
chetrf.f chetri.f chetri2.f chetri2x.f cheswapr.f
chetrs.f chetrs2.f
- chesv_aasen.f chetrf_aasen.f chetrs_aasen.f
+ chesv_aa.f chetrf_aa.f chetrs_aa.f
chetf2_rook.f chetrf_rook.f chetri_rook.f chetrs_rook.f checon_rook.f chesv_rook.f
chgeqz.f chpcon.f chpev.f chpevd.f
chpevx.f chpgst.f chpgv.f chpgvd.f chpgvx.f chprfs.f chpsv.f
@@ -198,7 +198,7 @@ set(CLASRC
clacgv.f clacon.f clacn2.f clacp2.f clacpy.f clacrm.f clacrt.f cladiv.f
claed0.f claed7.f claed8.f
claein.f claesy.f claev2.f clags2.f clagtm.f
- clahef.f clahef_rook.f clahef_aasen.f clahqr.f
+ clahef.f clahef_rook.f clahef_aa.f clahqr.f
clahr2.f claic1.f clals0.f clalsa.f clalsd.f clangb.f clange.f clangt.f
clanhb.f clanhe.f
clanhp.f clanhs.f clanht.f clansb.f clansp.f clansy.f clantb.f
@@ -283,7 +283,7 @@ set(DLASRC
dlaqtr.f dlar1v.f dlar2v.f iladlr.f iladlc.f
dlarf.f dlarfb.f dlarfg.f dlarfgp.f dlarft.f dlarfx.f dlargv.f
dlarrv.f dlartv.f
- dlarz.f dlarzb.f dlarzt.f dlaswp.f dlasy2.f dlasyf.f dlasyf_rook.f dlasyf_aasen.f
+ dlarz.f dlarzb.f dlarzt.f dlaswp.f dlasy2.f dlasyf.f dlasyf_rook.f dlasyf_aa.f
dlatbs.f dlatdf.f dlatps.f dlatrd.f dlatrs.f dlatrz.f dlauu2.f
dlauum.f dopgtr.f dopmtr.f dorg2l.f dorg2r.f
dorgbr.f dorghr.f dorgl2.f dorglq.f dorgql.f dorgqr.f dorgr2.f
@@ -305,7 +305,7 @@ set(DLASRC
dsysv.f dsysvx.f
dsytd2.f dsytf2.f dsytrd.f dsytrf.f dsytri.f dsytrs.f dsytrs2.f
dsytri2.f dsytri2x.f dsyswapr.f dsyconv.f
- dsysv_aasen.f dsytrf_aasen.f dsytrs_aasen.f
+ dsysv_aa.f dsytrf_aa.f dsytrs_aa.f
dsytf2_rook.f dsytrf_rook.f dsytrs_rook.f
dsytri_rook.f dsycon_rook.f dsysv_rook.f
dtbcon.f
@@ -358,7 +358,7 @@ set(ZLASRC
zhetf2.f zhetrd.f
zhetrf.f zhetri.f zhetri2.f zhetri2x.f zheswapr.f
zhetrs.f zhetrs2.f
- zhesv_aasen.f zhetrf_aasen.f zhetrs_aasen.f
+ zhesv_aa.f zhetrf_aa.f zhetrs_aa.f
zhetf2_rook.f zhetrf_rook.f zhetri_rook.f zhetrs_rook.f zhecon_rook.f zhesv_rook.f
zhgeqz.f zhpcon.f zhpev.f zhpevd.f
zhpevx.f zhpgst.f zhpgv.f zhpgvd.f zhpgvx.f zhprfs.f zhpsv.f
@@ -367,7 +367,7 @@ set(ZLASRC
zlacgv.f zlacon.f zlacn2.f zlacp2.f zlacpy.f zlacrm.f zlacrt.f zladiv.f
zlaed0.f zlaed7.f zlaed8.f
zlaein.f zlaesy.f zlaev2.f zlags2.f zlagtm.f
- zlahef.f zlahef_rook.f zlahef_aasen.f zlahqr.f
+ zlahef.f zlahef_rook.f zlahef_aa.f zlahqr.f
zlahr2.f zlaic1.f zlals0.f zlalsa.f zlalsd.f zlangb.f zlange.f
zlangt.f zlanhb.f
zlanhe.f
diff --git a/SRC/Makefile b/SRC/Makefile
index d7c1bd43..33058ec8 100644
--- a/SRC/Makefile
+++ b/SRC/Makefile
@@ -145,7 +145,7 @@ SLASRC = \
ssytd2.o ssytf2.o ssytrd.o ssytrf.o ssytri.o ssytri2.o ssytri2x.o \
ssyswapr.o ssytrs.o ssytrs2.o ssyconv.o \
ssytf2_rook.o ssytrf_rook.o ssytrs_rook.o \
- slasyf_aasen.o ssysv_aasen.o ssytrf_aasen.o ssytrs_aasen.o \
+ slasyf_aa.o ssysv_aa.o ssytrf_aa.o ssytrs_aa.o \
ssytri_rook.o ssycon_rook.o ssysv_rook.o \
stbcon.o \
stbrfs.o stbtrs.o stgevc.o stgex2.o stgexc.o stgsen.o \
@@ -201,7 +201,7 @@ CLASRC = \
chetrf.o chetri.o chetri2.o chetri2x.o cheswapr.o \
chetrs.o chetrs2.o \
chetf2_rook.o chetrf_rook.o chetri_rook.o chetrs_rook.o checon_rook.o chesv_rook.o \
- chesv_aasen.o chetrf_aasen.o chetrs_aasen.o clahef_aasen.o\
+ chesv_aa.o chetrf_aa.o chetrs_aa.o clahef_aa.o\
chgeqz.o chpcon.o chpev.o chpevd.o \
chpevx.o chpgst.o chpgv.o chpgvd.o chpgvx.o chprfs.o chpsv.o \
chpsvx.o \
@@ -322,7 +322,7 @@ DLASRC = \
dsytd2.o dsytf2.o dsytrd.o dsytrf.o dsytri.o dsytri2.o dsytri2x.o \
dsyswapr.o dsytrs.o dsytrs2.o dsyconv.o \
dsytf2_rook.o dsytrf_rook.o dsytrs_rook.o \
- dlasyf_aasen.o dsysv_aasen.o dsytrf_aasen.o dsytrs_aasen.o \
+ dlasyf_aa.o dsysv_aa.o dsytrf_aa.o dsytrs_aa.o \
dsytri_rook.o dsycon_rook.o dsysv_rook.o \
dtbcon.o dtbrfs.o dtbtrs.o dtgevc.o dtgex2.o dtgexc.o dtgsen.o \
dtgsja.o dtgsna.o dtgsy2.o dtgsyl.o dtpcon.o dtprfs.o dtptri.o \
@@ -377,7 +377,7 @@ ZLASRC = \
zhetrf.o zhetri.o zhetri2.o zhetri2x.o zheswapr.o \
zhetrs.o zhetrs2.o \
zhetf2_rook.o zhetrf_rook.o zhetri_rook.o zhetrs_rook.o zhecon_rook.o zhesv_rook.o \
- zhesv_aasen.o zhetrf_aasen.o zhetrs_aasen.o zlahef_aasen.o \
+ zhesv_aa.o zhetrf_aa.o zhetrs_aa.o zlahef_aa.o \
zhgeqz.o zhpcon.o zhpev.o zhpevd.o \
zhpevx.o zhpgst.o zhpgv.o zhpgvd.o zhpgvx.o zhprfs.o zhpsv.o \
zhpsvx.o \
diff --git a/SRC/chesv_aasen.f b/SRC/chesv_aa.f
index 0dd2917e..382eb884 100644
--- a/SRC/chesv_aasen.f
+++ b/SRC/chesv_aa.f
@@ -1,4 +1,4 @@
*> \brief <b> CHESV_AASEN computes the solution to system of linear equations A * X = B for HE matrices</b>
*
* =========== DOCUMENTATION ===========
*
@@ -6,19 +6,19 @@
* http://www.netlib.org/lapack/explore-html/
*
*> \htmlonly
-*> Download CHESV_AASEN + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/chesv_aasen.f">
+*> Download CHESV_AA + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/chesv_aa.f">
*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/chesv_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/chesv_aa.f">
*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/chesv_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/chesv_aa.f">
*> [TXT]</a>
*> \endhtmlonly
*
* Definition:
* ===========
*
* SUBROUTINE CHESV_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
* LWORK, INFO )
*
* .. Scalar Arguments ..
@@ -36,7 +36,7 @@
*>
*> \verbatim
*>
*> CHESV_AASEN computes the solution to a complex system of linear equations
*> A * X = B,
*> where A is an N-by-N Hermitian matrix and X and B are N-by-NRHS
*> matrices.
@@ -87,7 +87,7 @@
*> On exit, if INFO = 0, the tridiagonal matrix T and the
*> multipliers used to obtain the factor U or L from the
*> factorization A = U*T*U**H or A = L*T*L**H as computed by
-*> CHETRF_AASEN.
+*> CHETRF_AA.
*> \endverbatim
*>
*> \param[in] LDA
@@ -161,7 +161,7 @@
*> \ingroup complexHEsolve
*
* =====================================================================
- SUBROUTINE CHESV_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
+ SUBROUTINE CHESV_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
$ LWORK, INFO )
*
* -- LAPACK driver routine (version 3.7.0) --
@@ -216,13 +216,13 @@
END IF
*
IF( INFO.EQ.0 ) THEN
- NB = ILAENV( 1, 'CHETRF_AASEN', UPLO, N, -1, -1, -1 )
+ NB = ILAENV( 1, 'CHETRF_AA', UPLO, N, -1, -1, -1 )
LWKOPT = MAX( 3*N-2, (1+NB)*N )
WORK( 1 ) = LWKOPT
END IF
*
IF( INFO.NE.0 ) THEN
- CALL XERBLA( 'CHESV_AASEN ', -INFO )
+ CALL XERBLA( 'CHESV_AA ', -INFO )
RETURN
ELSE IF( LQUERY ) THEN
RETURN
@@ -230,12 +230,12 @@
*
* Compute the factorization A = U*T*U**H or A = L*T*L**H.
*
- CALL CHETRF_AASEN( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
+ CALL CHETRF_AA( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
IF( INFO.EQ.0 ) THEN
*
* Solve the system A*X = B, overwriting B with X.
*
- CALL CHETRS_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
+ CALL CHETRS_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
$ LWORK, INFO )
*
END IF
@@ -244,6 +244,6 @@
*
RETURN
*
-* End of CHESV_AASEN
+* End of CHESV_AA
*
END
@@ -1,4 +1,4 @@
-*> \brief <b> CHESV_AASEN computes the solution to system of linear equations A * X = B for HE matrices</b>
+*> \brief <b> CHESV_AA computes the solution to system of linear equations A * X = B for HE matrices</b>
*
* =========== DOCUMENTATION ===========
@@ -6,19 +6,19 @@
* ===========
*
-* SUBROUTINE CHESV_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
+* SUBROUTINE CHESV_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
* LWORK, INFO )
*
@@ -36,7 +36,7 @@
*> \verbatim
*>
-*> CHESV_AASEN computes the solution to a complex system of linear equations
+*> CHESV_AA computes the solution to a complex system of linear equations
*> A * X = B,
*> where A is an N-by-N Hermitian matrix and X and B are N-by-NRHS
diff --git a/SRC/chetrf_aasen.f b/SRC/chetrf_aa.f
index d280032d..883e9f00 100644
--- a/SRC/chetrf_aasen.f
+++ b/SRC/chetrf_aa.f
@@ -1,4 +1,4 @@
-*> \brief \b CHETRF_AASEN
+*> \brief \b CHETRF_AA
*
* =========== DOCUMENTATION ===========
*
@@ -6,19 +6,19 @@
* http://www.netlib.org/lapack/explore-html/
*
*> \htmlonly
-*> Download CHETRF_AASEN + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/chetrf_aasen.f">
+*> Download CHETRF_AA + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/chetrf_aa.f">
*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/chetrf_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/chetrf_aa.f">
*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/chetrf_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/chetrf_aa.f">
*> [TXT]</a>
*> \endhtmlonly
*
* Definition:
* ===========
*
* SUBROUTINE CHETRF_AASEN( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
*
* .. Scalar Arguments ..
* CHARACTER UPLO
@@ -34,7 +34,7 @@
*>
*> \verbatim
*>
*> CHETRF_AASEN computes the factorization of a complex hermitian matrix A
*> using the Aasen's algorithm. The form of the factorization is
*>
*> A = U*T*U**T or A = L*T*L**T
@@ -134,7 +134,7 @@
*> \ingroup complexHEcomputational
*
* =====================================================================
- SUBROUTINE CHETRF_AASEN( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO)
+ SUBROUTINE CHETRF_AA( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO)
*
* -- LAPACK computational routine (version 3.7.0) --
* -- LAPACK is a software package provided by Univ. of Tennessee, --
@@ -201,7 +201,7 @@
END IF
*
IF( INFO.NE.0 ) THEN
- CALL XERBLA( 'CHETRF_AASEN', -INFO )
+ CALL XERBLA( 'CHETRF_AA', -INFO )
RETURN
ELSE IF( LQUERY ) THEN
RETURN
@@ -259,7 +259,7 @@
*
* Panel factorization
*
- CALL CLAHEF_AASEN( UPLO, 2-K1, N-J, JB,
+ CALL CLAHEF_AA( UPLO, 2-K1, N-J, JB,
$ A( MAX(1, J), J+1 ), LDA,
$ IPIV( J+1 ), WORK, N, WORK( N*NB+1 ),
$ IINFO )
@@ -383,7 +383,7 @@
*
* Panel factorization
*
- CALL CLAHEF_AASEN( UPLO, 2-K1, N-J, JB,
+ CALL CLAHEF_AA( UPLO, 2-K1, N-J, JB,
$ A( J+1, MAX(1, J) ), LDA,
$ IPIV( J+1 ), WORK, N, WORK( N*NB+1 ), IINFO)
IF( (IINFO.GT.0) .AND. (INFO.EQ.0) ) THEN
@@ -478,6 +478,6 @@
20 CONTINUE
RETURN
*
-* End of CHETRF_AASEN
+* End of CHETRF_AA
*
END
@@ -6,19 +6,19 @@
* ===========
*
-* SUBROUTINE CHETRF_AASEN( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
+* SUBROUTINE CHETRF_AA( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
*
* .. Scalar Arguments ..
@@ -34,7 +34,7 @@
*> \verbatim
*>
-*> CHETRF_AASEN computes the factorization of a complex hermitian matrix A
+*> CHETRF_AA computes the factorization of a complex hermitian matrix A
*> using the Aasen's algorithm. The form of the factorization is
*>
diff --git a/SRC/chetrs_aasen.f b/SRC/chetrs_aa.f
index 6de3d954..f3ef27a4 100644
--- a/SRC/chetrs_aasen.f
+++ b/SRC/chetrs_aa.f
@@ -1,4 +1,4 @@
-*> \brief \b CHETRS_AASEN
+*> \brief \b CHETRS_AA
*
* =========== DOCUMENTATION ===========
*
@@ -6,19 +6,19 @@
* http://www.netlib.org/lapack/explore-html/
*
*> \htmlonly
-*> Download CHETRS_AASEN + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/chetrs_aasen.f">
+*> Download CHETRS_AA + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/chetrs_aa.f">
*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/chetrs_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/chetrs_aa.f">
*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/chetrs_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/chetrs_aa.f">
*> [TXT]</a>
*> \endhtmlonly
*
* Definition:
* ===========
*
* SUBROUTINE CHETRS_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
* WORK, LWORK, INFO )
*
* .. Scalar Arguments ..
@@ -36,9 +36,9 @@
*>
*> \verbatim
*>
*> CHETRS_AASEN solves a system of linear equations A*X = B with a real
*> hermitian matrix A using the factorization A = U*T*U**T or
-*> A = L*T*L**T computed by CHETRF_AASEN.
+*> A = L*T*L**T computed by CHETRF_AA.
*> \endverbatim
*
* Arguments:
@@ -69,7 +69,7 @@
*> \param[in,out] A
*> \verbatim
*> A is COMPLEX array, dimension (LDA,N)
-*> Details of factors computed by CHETRF_AASEN.
+*> Details of factors computed by CHETRF_AA.
*> \endverbatim
*>
*> \param[in] LDA
@@ -81,7 +81,7 @@
*> \param[in] IPIV
*> \verbatim
*> IPIV is INTEGER array, dimension (N)
-*> Details of the interchanges as computed by CHETRF_AASEN.
+*> Details of the interchanges as computed by CHETRF_AA.
*> \endverbatim
*>
*> \param[in,out] B
@@ -126,7 +126,7 @@
*> \ingroup complexHEcomputational
*
* =====================================================================
- SUBROUTINE CHETRS_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
+ SUBROUTINE CHETRS_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
$ WORK, LWORK, INFO )
*
* -- LAPACK computational routine (version 3.7.0) --
@@ -183,7 +183,7 @@
INFO = -10
END IF
IF( INFO.NE.0 ) THEN
- CALL XERBLA( 'CHETRS_AASEN', -INFO )
+ CALL XERBLA( 'CHETRS_AA', -INFO )
RETURN
ELSE IF( LQUERY ) THEN
LWKOPT = (3*N-2)
@@ -290,6 +290,6 @@
*
RETURN
*
-* End of CHETRS_AASEN
+* End of CHETRS_AA
*
END
@@ -6,19 +6,19 @@
* ===========
*
-* SUBROUTINE CHETRS_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
+* SUBROUTINE CHETRS_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
* WORK, LWORK, INFO )
*
@@ -36,9 +36,9 @@
*> \verbatim
*>
-*> CHETRS_AASEN solves a system of linear equations A*X = B with a real
+*> CHETRS_AA solves a system of linear equations A*X = B with a real
*> hermitian matrix A using the factorization A = U*T*U**T or
diff --git a/SRC/clahef_aasen.f b/SRC/clahef_aa.f
index 9f83315d..91027181 100644
--- a/SRC/clahef_aasen.f
+++ b/SRC/clahef_aa.f
@@ -1,4 +1,4 @@
-*> \brief \b CLAHEF_AASEN
+*> \brief \b CLAHEF_AA
*
* =========== DOCUMENTATION ===========
*
@@ -6,19 +6,19 @@
* http://www.netlib.org/lapack/explore-html/
*
*> \htmlonly
-*> Download CLAHEF_AASEN + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/clahef_aasen.f">
+*> Download CLAHEF_AA + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/clahef_aa.f">
*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/clahef_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/clahef_aa.f">
*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/clahef_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/clahef_aa.f">
*> [TXT]</a>
*> \endhtmlonly
*
* Definition:
* ===========
*
* SUBROUTINE CLAHEF_AASEN( UPLO, J1, M, NB, A, LDA, IPIV,
* H, LDH, WORK, INFO )
*
* .. Scalar Arguments ..
@@ -36,7 +36,7 @@
*>
*> \verbatim
*>
-*> DLATRF_AASEN factorizes a panel of a real hermitian matrix A using
+*> DLATRF_AA factorizes a panel of a real hermitian matrix A using
*> the Aasen's algorithm. The panel consists of a set of NB rows of A
*> when UPLO is U, or a set of NB columns when UPLO is L.
*>
@@ -66,7 +66,7 @@
*> J1 is INTEGER
*> The location of the first row, or column, of the panel
*> within the submatrix of A, passed to this routine, e.g.,
-*> when called by CHETRF_AASEN, for the first panel, J1 is 1,
+*> when called by CHETRF_AA, for the first panel, J1 is 1,
*> while for the remaining panels, J1 is 2.
*> \endverbatim
*>
@@ -151,7 +151,7 @@
*> \ingroup complexSYcomputational
*
* =====================================================================
- SUBROUTINE CLAHEF_AASEN( UPLO, J1, M, NB, A, LDA, IPIV,
+ SUBROUTINE CLAHEF_AA( UPLO, J1, M, NB, A, LDA, IPIV,
$ H, LDH, WORK, INFO )
*
* -- LAPACK computational routine (version 3.7.0) --
@@ -211,7 +211,7 @@
$ GO TO 20
*
* K is the column to be factorized
-* when being called from CHETRF_AASEN,
+* when being called from CHETRF_AA,
* > for the first block column, J1 is 1, hence J1+J-1 is J,
* > for the rest of the columns, J1 is 2, and J1+J-1 is J+1,
*
@@ -365,7 +365,7 @@
$ GO TO 40
*
* K is the column to be factorized
-* when being called from CHETRF_AASEN,
+* when being called from CHETRF_AA,
* > for the first block column, J1 is 1, hence J1+J-1 is J,
* > for the rest of the columns, J1 is 2, and J1+J-1 is J+1,
*
@@ -508,6 +508,6 @@
END IF
RETURN
*
-* End of CLAHEF_AASEN
+* End of CLAHEF_AA
*
END
@@ -6,19 +6,19 @@
* ===========
*
-* SUBROUTINE CLAHEF_AASEN( UPLO, J1, M, NB, A, LDA, IPIV,
+* SUBROUTINE CLAHEF_AA( UPLO, J1, M, NB, A, LDA, IPIV,
* H, LDH, WORK, INFO )
*
diff --git a/SRC/dlasyf_aasen.f b/SRC/dlasyf_aa.f
index 14d9fdda..73279117 100644
--- a/SRC/dlasyf_aasen.f
+++ b/SRC/dlasyf_aa.f
@@ -1,4 +1,4 @@
-*> \brief \b DLASYF_AASEN
+*> \brief \b DLASYF_AA
*
* =========== DOCUMENTATION ===========
*
@@ -6,19 +6,19 @@
* http://www.netlib.org/lapack/explore-html/
*
*> \htmlonly
-*> Download DLASYF_AASEN + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/dlasyf_aasen.f">
+*> Download DLASYF_AA + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/dlasyf_aa.f">
*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/dlasyf_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/dlasyf_aa.f">
*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/dlasyf_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/dlasyf_aa.f">
*> [TXT]</a>
*> \endhtmlonly
*
* Definition:
* ===========
*
* SUBROUTINE DLASYF_AASEN( UPLO, J1, M, NB, A, LDA, IPIV,
* H, LDH, WORK, INFO )
*
* .. Scalar Arguments ..
@@ -36,7 +36,7 @@
*>
*> \verbatim
*>
-*> DLATRF_AASEN factorizes a panel of a real symmetric matrix A using
+*> DLATRF_AA factorizes a panel of a real symmetric matrix A using
*> the Aasen's algorithm. The panel consists of a set of NB rows of A
*> when UPLO is U, or a set of NB columns when UPLO is L.
*>
@@ -66,7 +66,7 @@
*> J1 is INTEGER
*> The location of the first row, or column, of the panel
*> within the submatrix of A, passed to this routine, e.g.,
-*> when called by DSYTRF_AASEN, for the first panel, J1 is 1,
+*> when called by DSYTRF_AA, for the first panel, J1 is 1,
*> while for the remaining panels, J1 is 2.
*> \endverbatim
*>
@@ -151,7 +151,7 @@
*> \ingroup doubleSYcomputational
*
* =====================================================================
- SUBROUTINE DLASYF_AASEN( UPLO, J1, M, NB, A, LDA, IPIV,
+ SUBROUTINE DLASYF_AA( UPLO, J1, M, NB, A, LDA, IPIV,
$ H, LDH, WORK, INFO )
*
* -- LAPACK computational routine (version 3.7.0) --
@@ -211,7 +211,7 @@
$ GO TO 20
*
* K is the column to be factorized
-* when being called from DSYTRF_AASEN,
+* when being called from DSYTRF_AA,
* > for the first block column, J1 is 1, hence J1+J-1 is J,
* > for the rest of the columns, J1 is 2, and J1+J-1 is J+1,
*
@@ -361,7 +361,7 @@
$ GO TO 40
*
* K is the column to be factorized
-* when being called from DSYTRF_AASEN,
+* when being called from DSYTRF_AA,
* > for the first block column, J1 is 1, hence J1+J-1 is J,
* > for the rest of the columns, J1 is 2, and J1+J-1 is J+1,
*
@@ -501,6 +501,6 @@
END IF
RETURN
*
-* End of DLASYF_AASEN
+* End of DLASYF_AA
*
END
@@ -6,19 +6,19 @@
* ===========
*
-* SUBROUTINE DLASYF_AASEN( UPLO, J1, M, NB, A, LDA, IPIV,
+* SUBROUTINE DLASYF_AA( UPLO, J1, M, NB, A, LDA, IPIV,
* H, LDH, WORK, INFO )
*
diff --git a/SRC/dsysv_aasen.f b/SRC/dsysv_aa.f
index c65f11f2..06bcdc93 100644
--- a/SRC/dsysv_aasen.f
+++ b/SRC/dsysv_aa.f
@@ -1,4 +1,4 @@
*> \brief <b> DSYSV_AASEN computes the solution to system of linear equations A * X = B for SY matrices</b>
*
* =========== DOCUMENTATION ===========
*
@@ -6,19 +6,19 @@
* http://www.netlib.org/lapack/explore-html/
*
*> \htmlonly
-*> Download DSYSV_AASEN + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/dsysv_aasen.f">
+*> Download DSYSV_AA + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/dsysv_aa.f">
*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/dsysv_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/dsysv_aa.f">
*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/dsysv_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/dsysv_aa.f">
*> [TXT]</a>
*> \endhtmlonly
*
* Definition:
* ===========
*
* SUBROUTINE DSYSV_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
* LWORK, INFO )
*
* .. Scalar Arguments ..
@@ -128,7 +128,7 @@
*> LWORK is INTEGER
*> The length of WORK. LWORK >= MAX(2*N, 3*N-2), and for
*> the best performance, LWORK >= max(1,N*NB), where NB is
*> the optimal blocksize for DSYTRF_AASEN.
*>
*> If LWORK = -1, then a workspace query is assumed; the routine
*> only calculates the optimal size of the WORK array, returns
@@ -159,7 +159,7 @@
*> \ingroup doubleSYsolve
*
* =====================================================================
- SUBROUTINE DSYSV_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
+ SUBROUTINE DSYSV_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
$ LWORK, INFO )
*
* -- LAPACK driver routine (version 3.7.0) --
@@ -214,13 +214,13 @@
END IF
*
IF( INFO.EQ.0 ) THEN
- NB = ILAENV( 1, 'DSYTRF_AASEN', UPLO, N, -1, -1, -1 )
+ NB = ILAENV( 1, 'DSYTRF_AA', UPLO, N, -1, -1, -1 )
LWKOPT = MAX( 3*N-2, (1+NB)*N )
WORK( 1 ) = LWKOPT
END IF
*
IF( INFO.NE.0 ) THEN
- CALL XERBLA( 'DSYSV_AASEN ', -INFO )
+ CALL XERBLA( 'DSYSV_AA ', -INFO )
RETURN
ELSE IF( LQUERY ) THEN
RETURN
@@ -228,12 +228,12 @@
*
* Compute the factorization A = U*T*U**T or A = L*T*L**T.
*
- CALL DSYTRF_AASEN( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
+ CALL DSYTRF_AA( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
IF( INFO.EQ.0 ) THEN
*
* Solve the system A*X = B, overwriting B with X.
*
- CALL DSYTRS_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
+ CALL DSYTRS_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
$ LWORK, INFO )
*
END IF
@@ -242,6 +242,6 @@
*
RETURN
*
-* End of DSYSV_AASEN
+* End of DSYSV_AA
*
END
@@ -1,4 +1,4 @@
-*> \brief <b> DSYSV_AASEN computes the solution to system of linear equations A * X = B for SY matrices</b>
+*> \brief <b> DSYSV_AA computes the solution to system of linear equations A * X = B for SY matrices</b>
*
* =========== DOCUMENTATION ===========
@@ -6,19 +6,19 @@
* ===========
*
-* SUBROUTINE DSYSV_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
+* SUBROUTINE DSYSV_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
* LWORK, INFO )
*
@@ -128,7 +128,7 @@
*> The length of WORK. LWORK >= MAX(2*N, 3*N-2), and for
*> the best performance, LWORK >= max(1,N*NB), where NB is
-*> the optimal blocksize for DSYTRF_AASEN.
+*> the optimal blocksize for DSYTRF_AA.
*>
*> If LWORK = -1, then a workspace query is assumed; the routine
diff --git a/SRC/dsytrf_aasen.f b/SRC/dsytrf_aa.f
index 581c4beb..07919a2c 100644
--- a/SRC/dsytrf_aasen.f
+++ b/SRC/dsytrf_aa.f
@@ -1,4 +1,4 @@
-*> \brief \b DSYTRF_AASEN
+*> \brief \b DSYTRF_AA
*
* =========== DOCUMENTATION ===========
*
@@ -6,19 +6,19 @@
* http://www.netlib.org/lapack/explore-html/
*
*> \htmlonly
-*> Download DSYTRF_AASEN + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/dsytrf_aasen.f">
+*> Download DSYTRF_AA + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/dsytrf_aa.f">
*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/dsytrf_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/dsytrf_aa.f">
*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/dsytrf_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/dsytrf_aa.f">
*> [TXT]</a>
*> \endhtmlonly
*
* Definition:
* ===========
*
* SUBROUTINE DSYTRF_AASEN( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
*
* .. Scalar Arguments ..
* CHARACTER UPLO
@@ -34,7 +34,7 @@
*>
*> \verbatim
*>
*> DSYTRF_AASEN computes the factorization of a real symmetric matrix A
*> using the Aasen's algorithm. The form of the factorization is
*>
*> A = U*T*U**T or A = L*T*L**T
@@ -134,7 +134,7 @@
*> \ingroup doubleSYcomputational
*
* =====================================================================
- SUBROUTINE DSYTRF_AASEN( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO)
+ SUBROUTINE DSYTRF_AA( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO)
*
* -- LAPACK computational routine (version 3.7.0) --
* -- LAPACK is a software package provided by Univ. of Tennessee, --
@@ -201,7 +201,7 @@
END IF
*
IF( INFO.NE.0 ) THEN
- CALL XERBLA( 'DSYTRF_AASEN', -INFO )
+ CALL XERBLA( 'DSYTRF_AA', -INFO )
RETURN
ELSE IF( LQUERY ) THEN
RETURN
@@ -258,7 +258,7 @@
*
* Panel factorization
*
- CALL DLASYF_AASEN( UPLO, 2-K1, N-J, JB,
+ CALL DLASYF_AA( UPLO, 2-K1, N-J, JB,
$ A( MAX(1, J), J+1 ), LDA,
$ IPIV( J+1 ), WORK, N, WORK( N*NB+1 ),
$ IINFO )
@@ -381,7 +381,7 @@
*
* Panel factorization
*
- CALL DLASYF_AASEN( UPLO, 2-K1, N-J, JB,
+ CALL DLASYF_AA( UPLO, 2-K1, N-J, JB,
$ A( J+1, MAX(1, J) ), LDA,
$ IPIV( J+1 ), WORK, N, WORK( N*NB+1 ), IINFO)
IF( (IINFO.GT.0) .AND. (INFO.EQ.0) ) THEN
@@ -475,6 +475,6 @@
20 CONTINUE
RETURN
*
-* End of DSYTRF_AASEN
+* End of DSYTRF_AA
*
END
@@ -6,19 +6,19 @@
* ===========
*
-* SUBROUTINE DSYTRF_AASEN( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
+* SUBROUTINE DSYTRF_AA( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
*
* .. Scalar Arguments ..
@@ -34,7 +34,7 @@
*> \verbatim
*>
-*> DSYTRF_AASEN computes the factorization of a real symmetric matrix A
+*> DSYTRF_AA computes the factorization of a real symmetric matrix A
*> using the Aasen's algorithm. The form of the factorization is
*>
diff --git a/SRC/dsytrs_aasen.f b/SRC/dsytrs_aa.f
index f4397326..a0774f10 100644
--- a/SRC/dsytrs_aasen.f
+++ b/SRC/dsytrs_aa.f
@@ -1,4 +1,4 @@
-*> \brief \b DSYTRS_AASEN
+*> \brief \b DSYTRS_AA
*
* =========== DOCUMENTATION ===========
*
@@ -6,19 +6,19 @@
* http://www.netlib.org/lapack/explore-html/
*
*> \htmlonly
-*> Download DSYTRS_AASEN + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/dsytrs_aasen.f">
+*> Download DSYTRS_AA + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/dsytrs_aa.f">
*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/dsytrs_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/dsytrs_aa.f">
*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/dsytrs_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/dsytrs_aa.f">
*> [TXT]</a>
*> \endhtmlonly
*
* Definition:
* ===========
*
* SUBROUTINE DSYTRS_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
* WORK, LWORK, INFO )
*
* .. Scalar Arguments ..
@@ -36,9 +36,9 @@
*>
*> \verbatim
*>
*> DSYTRS_AASEN solves a system of linear equations A*X = B with a real
*> symmetric matrix A using the factorization A = U*T*U**T or
-*> A = L*T*L**T computed by DSYTRF_AASEN.
+*> A = L*T*L**T computed by DSYTRF_AA.
*> \endverbatim
*
* Arguments:
@@ -69,7 +69,7 @@
*> \param[in,out] A
*> \verbatim
*> A is DOUBLE PRECISION array, dimension (LDA,N)
-*> Details of factors computed by DSYTRF_AASEN.
+*> Details of factors computed by DSYTRF_AA.
*> \endverbatim
*>
*> \param[in] LDA
@@ -81,7 +81,7 @@
*> \param[in] IPIV
*> \verbatim
*> IPIV is INTEGER array, dimension (N)
-*> Details of the interchanges as computed by DSYTRF_AASEN.
+*> Details of the interchanges as computed by DSYTRF_AA.
*> \endverbatim
*>
*> \param[in,out] B
@@ -126,7 +126,7 @@
*> \ingroup doubleSYcomputational
*
* =====================================================================
- SUBROUTINE DSYTRS_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
+ SUBROUTINE DSYTRS_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
$ WORK, LWORK, INFO )
*
* -- LAPACK computational routine (version 3.7.0) --
@@ -183,7 +183,7 @@
INFO = -10
END IF
IF( INFO.NE.0 ) THEN
- CALL XERBLA( 'DSYTRS_AASEN', -INFO )
+ CALL XERBLA( 'DSYTRS_AA', -INFO )
RETURN
ELSE IF( LQUERY ) THEN
LWKOPT = (3*N-2)
@@ -280,6 +280,6 @@
*
RETURN
*
-* End of DSYTRS_AASEN
+* End of DSYTRS_AA
*
END
@@ -6,19 +6,19 @@
* ===========
*
-* SUBROUTINE DSYTRS_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
+* SUBROUTINE DSYTRS_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
* WORK, LWORK, INFO )
*
@@ -36,9 +36,9 @@
*> \verbatim
*>
-*> DSYTRS_AASEN solves a system of linear equations A*X = B with a real
+*> DSYTRS_AA solves a system of linear equations A*X = B with a real
*> symmetric matrix A using the factorization A = U*T*U**T or
diff --git a/SRC/slasyf_aasen.f b/SRC/slasyf_aa.f
index 383e5046..6436fd8a 100644
--- a/SRC/slasyf_aasen.f
+++ b/SRC/slasyf_aa.f
@@ -1,4 +1,4 @@
-*> \brief \b SLASYF_AASEN
+*> \brief \b SLASYF_AA
*
* =========== DOCUMENTATION ===========
*
@@ -6,19 +6,19 @@
* http://www.netlib.org/lapack/explore-html/
*
*> \htmlonly
-*> Download SLASYF_AASEN + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/slasyf_aasen.f">
+*> Download SLASYF_AA + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/slasyf_aa.f">
*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/slasyf_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/slasyf_aa.f">
*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/slasyf_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/slasyf_aa.f">
*> [TXT]</a>
*> \endhtmlonly
*
* Definition:
* ===========
*
* SUBROUTINE SLASYF_AASEN( UPLO, J1, M, NB, A, LDA, IPIV,
* H, LDH, WORK, INFO )
*
* .. Scalar Arguments ..
@@ -36,7 +36,7 @@
*>
*> \verbatim
*>
-*> DLATRF_AASEN factorizes a panel of a real symmetric matrix A using
+*> DLATRF_AA factorizes a panel of a real symmetric matrix A using
*> the Aasen's algorithm. The panel consists of a set of NB rows of A
*> when UPLO is U, or a set of NB columns when UPLO is L.
*>
@@ -66,7 +66,7 @@
*> J1 is INTEGER
*> The location of the first row, or column, of the panel
*> within the submatrix of A, passed to this routine, e.g.,
-*> when called by SSYTRF_AASEN, for the first panel, J1 is 1,
+*> when called by SSYTRF_AA, for the first panel, J1 is 1,
*> while for the remaining panels, J1 is 2.
*> \endverbatim
*>
@@ -151,7 +151,7 @@
*> \ingroup realSYcomputational
*
* =====================================================================
- SUBROUTINE SLASYF_AASEN( UPLO, J1, M, NB, A, LDA, IPIV,
+ SUBROUTINE SLASYF_AA( UPLO, J1, M, NB, A, LDA, IPIV,
$ H, LDH, WORK, INFO )
*
* -- LAPACK computational routine (version 3.7.0) --
@@ -211,7 +211,7 @@
$ GO TO 20
*
* K is the column to be factorized
-* when being called from SSYTRF_AASEN,
+* when being called from SSYTRF_AA,
* > for the first block column, J1 is 1, hence J1+J-1 is J,
* > for the rest of the columns, J1 is 2, and J1+J-1 is J+1,
*
@@ -361,7 +361,7 @@
$ GO TO 40
*
* K is the column to be factorized
-* when being called from SSYTRF_AASEN,
+* when being called from SSYTRF_AA,
* > for the first block column, J1 is 1, hence J1+J-1 is J,
* > for the rest of the columns, J1 is 2, and J1+J-1 is J+1,
*
@@ -501,6 +501,6 @@
END IF
RETURN
*
-* End of SLASYF_AASEN
+* End of SLASYF_AA
*
END
@@ -6,19 +6,19 @@
* ===========
*
-* SUBROUTINE SLASYF_AASEN( UPLO, J1, M, NB, A, LDA, IPIV,
+* SUBROUTINE SLASYF_AA( UPLO, J1, M, NB, A, LDA, IPIV,
* H, LDH, WORK, INFO )
*
diff --git a/SRC/ssysv_aasen.f b/SRC/ssysv_aa.f
index a95caefa..aa3edf6f 100644
--- a/SRC/ssysv_aasen.f
+++ b/SRC/ssysv_aa.f
@@ -1,4 +1,4 @@
*> \brief <b> SSYSV_AASEN computes the solution to system of linear equations A * X = B for SY matrices</b>
*
* =========== DOCUMENTATION ===========
*
@@ -6,19 +6,19 @@
* http://www.netlib.org/lapack/explore-html/
*
*> \htmlonly
-*> Download SSYSV_AASEN + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/ssysv_aasen.f">
+*> Download SSYSV_AA + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/ssysv_aa.f">
*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/ssysv_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/ssysv_aa.f">
*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/ssysv_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/ssysv_aa.f">
*> [TXT]</a>
*> \endhtmlonly
*
* Definition:
* ===========
*
* SUBROUTINE SSYSV_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
* LWORK, INFO )
*
* .. Scalar Arguments ..
@@ -128,7 +128,7 @@
*> LWORK is INTEGER
*> The length of WORK. LWORK >= MAX(2*N, 3*N-2), and for
*> the best performance, LWORK >= max(1,N*NB), where NB is
*> the optimal blocksize for SSYTRF_AASEN.
*>
*> If LWORK = -1, then a workspace query is assumed; the routine
*> only calculates the optimal size of the WORK array, returns
@@ -159,7 +159,7 @@
*> \ingroup realSYsolve
*
* =====================================================================
- SUBROUTINE SSYSV_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
+ SUBROUTINE SSYSV_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
$ LWORK, INFO )
*
* -- LAPACK driver routine (version 3.7.0) --
@@ -220,7 +220,7 @@
END IF
*
IF( INFO.NE.0 ) THEN
- CALL XERBLA( 'SSYSV_AASEN', -INFO )
+ CALL XERBLA( 'SSYSV_AA', -INFO )
RETURN
ELSE IF( LQUERY ) THEN
RETURN
@@ -228,12 +228,12 @@
*
* Compute the factorization A = U*T*U**T or A = L*T*L**T.
*
- CALL SSYTRF_AASEN( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
+ CALL SSYTRF_AA( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
IF( INFO.EQ.0 ) THEN
*
* Solve the system A*X = B, overwriting B with X.
*
- CALL SSYTRS_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
+ CALL SSYTRS_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
$ LWORK, INFO )
*
END IF
@@ -242,6 +242,6 @@
*
RETURN
*
-* End of SSYSV_AASEN
+* End of SSYSV_AA
*
END
@@ -1,4 +1,4 @@
-*> \brief <b> SSYSV_AASEN computes the solution to system of linear equations A * X = B for SY matrices</b>
+*> \brief <b> SSYSV_AA computes the solution to system of linear equations A * X = B for SY matrices</b>
*
* =========== DOCUMENTATION ===========
@@ -6,19 +6,19 @@
* ===========
*
-* SUBROUTINE SSYSV_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
+* SUBROUTINE SSYSV_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
* LWORK, INFO )
*
@@ -128,7 +128,7 @@
*> The length of WORK. LWORK >= MAX(2*N, 3*N-2), and for
*> the best performance, LWORK >= max(1,N*NB), where NB is
-*> the optimal blocksize for SSYTRF_AASEN.
+*> the optimal blocksize for SSYTRF_AA.
*>
*> If LWORK = -1, then a workspace query is assumed; the routine
diff --git a/SRC/ssytrf_aasen.f b/SRC/ssytrf_aa.f
index be355c1f..13498c9b 100644
--- a/SRC/ssytrf_aasen.f
+++ b/SRC/ssytrf_aa.f
@@ -1,4 +1,4 @@
-*> \brief \b SSYTRF_AASEN
+*> \brief \b SSYTRF_AA
*
* =========== DOCUMENTATION ===========
*
@@ -6,19 +6,19 @@
* http://www.netlib.org/lapack/explore-html/
*
*> \htmlonly
-*> Download SSYTRF_AASEN + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/ssytrf_aasen.f">
+*> Download SSYTRF_AA + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/ssytrf_aa.f">
*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/ssytrf_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/ssytrf_aa.f">
*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/ssytrf_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/ssytrf_aa.f">
*> [TXT]</a>
*> \endhtmlonly
*
* Definition:
* ===========
*
* SUBROUTINE SSYTRF_AASEN( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
*
* .. Scalar Arguments ..
* CHARACTER UPLO
@@ -34,7 +34,7 @@
*>
*> \verbatim
*>
*> SSYTRF_AASEN computes the factorization of a real symmetric matrix A
*> using the Aasen's algorithm. The form of the factorization is
*>
*> A = U*T*U**T or A = L*T*L**T
@@ -134,7 +134,7 @@
*> \ingroup realSYcomputational
*
* =====================================================================
- SUBROUTINE SSYTRF_AASEN( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO)
+ SUBROUTINE SSYTRF_AA( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO)
*
* -- LAPACK computational routine (version 3.7.0) --
* -- LAPACK is a software package provided by Univ. of Tennessee, --
@@ -201,7 +201,7 @@
END IF
*
IF( INFO.NE.0 ) THEN
- CALL XERBLA( 'SSYTRF_AASEN', -INFO )
+ CALL XERBLA( 'SSYTRF_AA', -INFO )
RETURN
ELSE IF( LQUERY ) THEN
RETURN
@@ -258,7 +258,7 @@
*
* Panel factorization
*
- CALL SLASYF_AASEN( UPLO, 2-K1, N-J, JB,
+ CALL SLASYF_AA( UPLO, 2-K1, N-J, JB,
$ A( MAX(1, J), J+1 ), LDA,
$ IPIV( J+1 ), WORK, N, WORK( N*NB+1 ),
$ IINFO )
@@ -381,7 +381,7 @@
*
* Panel factorization
*
- CALL SLASYF_AASEN( UPLO, 2-K1, N-J, JB,
+ CALL SLASYF_AA( UPLO, 2-K1, N-J, JB,
$ A( J+1, MAX(1, J) ), LDA,
$ IPIV( J+1 ), WORK, N, WORK( N*NB+1 ), IINFO)
IF( (IINFO.GT.0) .AND. (INFO.EQ.0) ) THEN
@@ -475,6 +475,6 @@
20 CONTINUE
RETURN
*
-* End of SSYTRF_AASEN
+* End of SSYTRF_AA
*
END
@@ -6,19 +6,19 @@
* ===========
*
-* SUBROUTINE SSYTRF_AASEN( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
+* SUBROUTINE SSYTRF_AA( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
*
* .. Scalar Arguments ..
@@ -34,7 +34,7 @@
*> \verbatim
*>
-*> SSYTRF_AASEN computes the factorization of a real symmetric matrix A
+*> SSYTRF_AA computes the factorization of a real symmetric matrix A
*> using the Aasen's algorithm. The form of the factorization is
*>
diff --git a/SRC/ssytrs_aasen.f b/SRC/ssytrs_aa.f
index 890e2740..0d975003 100644
--- a/SRC/ssytrs_aasen.f
+++ b/SRC/ssytrs_aa.f
@@ -1,4 +1,4 @@
-*> \brief \b SSYTRS_AASEN
+*> \brief \b SSYTRS_AA
*
* =========== DOCUMENTATION ===========
*
@@ -6,19 +6,19 @@
* http://www.netlib.org/lapack/explore-html/
*
*> \htmlonly
-*> Download SSYTRS_AASEN + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/ssytrs_aasen.f">
+*> Download SSYTRS_AA + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/ssytrs_aa.f">
*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/ssytrs_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/ssytrs_aa.f">
*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/ssytrs_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/ssytrs_aa.f">
*> [TXT]</a>
*> \endhtmlonly
*
* Definition:
* ===========
*
* SUBROUTINE SSYTRS_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
* WORK, LWORK, INFO )
*
* .. Scalar Arguments ..
@@ -36,9 +36,9 @@
*>
*> \verbatim
*>
*> SSYTRS_AASEN solves a system of linear equations A*X = B with a real
*> symmetric matrix A using the factorization A = U*T*U**T or
-*> A = L*T*L**T computed by SSYTRF_AASEN.
+*> A = L*T*L**T computed by SSYTRF_AA.
*> \endverbatim
*
* Arguments:
@@ -69,7 +69,7 @@
*> \param[in,out] A
*> \verbatim
*> A is REAL array, dimension (LDA,N)
-*> Details of factors computed by SSYTRF_AASEN.
+*> Details of factors computed by SSYTRF_AA.
*> \endverbatim
*>
*> \param[in] LDA
@@ -81,7 +81,7 @@
*> \param[in] IPIV
*> \verbatim
*> IPIV is INTEGER array, dimension (N)
-*> Details of the interchanges as computed by SSYTRF_AASEN.
+*> Details of the interchanges as computed by SSYTRF_AA.
*> \endverbatim
*>
*> \param[in,out] B
@@ -126,7 +126,7 @@
*> \ingroup realSYcomputational
*
* =====================================================================
- SUBROUTINE SSYTRS_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
+ SUBROUTINE SSYTRS_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
$ WORK, LWORK, INFO )
*
* -- LAPACK computational routine (version 3.7.0) --
@@ -183,7 +183,7 @@
INFO = -10
END IF
IF( INFO.NE.0 ) THEN
- CALL XERBLA( 'SSYTRS_AASEN', -INFO )
+ CALL XERBLA( 'SSYTRS_AA', -INFO )
RETURN
ELSE IF( LQUERY ) THEN
LWKOPT = (3*N-2)
@@ -289,6 +289,6 @@
*
RETURN
*
-* End of SSYTRS_AASEN
+* End of SSYTRS_AA
*
END
@@ -6,19 +6,19 @@
* ===========
*
-* SUBROUTINE SSYTRS_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
+* SUBROUTINE SSYTRS_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
* WORK, LWORK, INFO )
*
@@ -36,9 +36,9 @@
*> \verbatim
*>
-*> SSYTRS_AASEN solves a system of linear equations A*X = B with a real
+*> SSYTRS_AA solves a system of linear equations A*X = B with a real
*> symmetric matrix A using the factorization A = U*T*U**T or
diff --git a/SRC/zhesv_aasen.f b/SRC/zhesv_aa.f
index 3ec55758..03f98049 100644
--- a/SRC/zhesv_aasen.f
+++ b/SRC/zhesv_aa.f
@@ -1,4 +1,4 @@
*> \brief <b> ZHESV_AASEN computes the solution to system of linear equations A * X = B for HE matrices</b>
*
* =========== DOCUMENTATION ===========
*
@@ -6,19 +6,19 @@
* http://www.netlib.org/lapack/explore-html/
*
*> \htmlonly
-*> Download ZHESV_AASEN + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/zhesv_aasen.f">
+*> Download ZHESV_AA + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/zhesv_aa.f">
*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/zhesv_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/zhesv_aa.f">
*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/zhesv_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/zhesv_aa.f">
*> [TXT]</a>
*> \endhtmlonly
*
* Definition:
* ===========
*
* SUBROUTINE ZHESV_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
* LWORK, INFO )
*
* .. Scalar Arguments ..
@@ -36,7 +36,7 @@
*>
*> \verbatim
*>
*> ZHESV_AASEN computes the solution to a complex system of linear equations
*> A * X = B,
*> where A is an N-by-N Hermitian matrix and X and B are N-by-NRHS
*> matrices.
@@ -87,7 +87,7 @@
*> On exit, if INFO = 0, the tridiagonal matrix T and the
*> multipliers used to obtain the factor U or L from the
*> factorization A = U*T*U**H or A = L*T*L**H as computed by
-*> ZHETRF_AASEN.
+*> ZHETRF_AA.
*> \endverbatim
*>
*> \param[in] LDA
@@ -161,7 +161,7 @@
*> \ingroup complex16HEsolve
*
* =====================================================================
- SUBROUTINE ZHESV_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
+ SUBROUTINE ZHESV_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
$ LWORK, INFO )
*
* -- LAPACK driver routine (version 3.7.0) --
@@ -216,13 +216,13 @@
END IF
*
IF( INFO.EQ.0 ) THEN
- NB = ILAENV( 1, 'ZHETRF_AASEN', UPLO, N, -1, -1, -1 )
+ NB = ILAENV( 1, 'ZHETRF_AA', UPLO, N, -1, -1, -1 )
LWKOPT = MAX( 3*N-2, (1+NB)*N )
WORK( 1 ) = LWKOPT
END IF
*
IF( INFO.NE.0 ) THEN
- CALL XERBLA( 'ZHESV_AASEN ', -INFO )
+ CALL XERBLA( 'ZHESV_AA ', -INFO )
RETURN
ELSE IF( LQUERY ) THEN
RETURN
@@ -230,12 +230,12 @@
*
* Compute the factorization A = U*T*U**H or A = L*T*L**H.
*
- CALL ZHETRF_AASEN( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
+ CALL ZHETRF_AA( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
IF( INFO.EQ.0 ) THEN
*
* Solve the system A*X = B, overwriting B with X.
*
- CALL ZHETRS_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
+ CALL ZHETRS_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
$ LWORK, INFO )
*
END IF
@@ -244,6 +244,6 @@
*
RETURN
*
-* End of ZHESV_AASEN
+* End of ZHESV_AA
*
END
@@ -1,4 +1,4 @@
-*> \brief <b> ZHESV_AASEN computes the solution to system of linear equations A * X = B for HE matrices</b>
+*> \brief <b> ZHESV_AA computes the solution to system of linear equations A * X = B for HE matrices</b>
*
* =========== DOCUMENTATION ===========
@@ -6,19 +6,19 @@
* ===========
*
-* SUBROUTINE ZHESV_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
+* SUBROUTINE ZHESV_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
* LWORK, INFO )
*
@@ -36,7 +36,7 @@
*> \verbatim
*>
-*> ZHESV_AASEN computes the solution to a complex system of linear equations
+*> ZHESV_AA computes the solution to a complex system of linear equations
*> A * X = B,
*> where A is an N-by-N Hermitian matrix and X and B are N-by-NRHS
diff --git a/SRC/zhetrf_aasen.f b/SRC/zhetrf_aa.f
index 3b82be9f..73a8383a 100644
--- a/SRC/zhetrf_aasen.f
+++ b/SRC/zhetrf_aa.f
@@ -1,4 +1,4 @@
-*> \brief \b ZHETRF_AASEN
+*> \brief \b ZHETRF_AA
*
* =========== DOCUMENTATION ===========
*
@@ -6,19 +6,19 @@
* http://www.netlib.org/lapack/explore-html/
*
*> \htmlonly
-*> Download ZHETRF_AASEN + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/zhetrf_aasen.f">
+*> Download ZHETRF_AA + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/zhetrf_aa.f">
*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/zhetrf_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/zhetrf_aa.f">
*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/zhetrf_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/zhetrf_aa.f">
*> [TXT]</a>
*> \endhtmlonly
*
* Definition:
* ===========
*
* SUBROUTINE ZHETRF_AASEN( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
*
* .. Scalar Arguments ..
* CHARACTER UPLO
@@ -34,7 +34,7 @@
*>
*> \verbatim
*>
*> ZHETRF_AASEN computes the factorization of a complex hermitian matrix A
*> using the Aasen's algorithm. The form of the factorization is
*>
*> A = U*T*U**T or A = L*T*L**T
@@ -134,7 +134,7 @@
*> \ingroup complex16HEcomputational
*
* =====================================================================
- SUBROUTINE ZHETRF_AASEN( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO)
+ SUBROUTINE ZHETRF_AA( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO)
*
* -- LAPACK computational routine (version 3.7.0) --
* -- LAPACK is a software package provided by Univ. of Tennessee, --
@@ -201,7 +201,7 @@
END IF
*
IF( INFO.NE.0 ) THEN
- CALL XERBLA( 'ZHETRF_AASEN', -INFO )
+ CALL XERBLA( 'ZHETRF_AA', -INFO )
RETURN
ELSE IF( LQUERY ) THEN
RETURN
@@ -259,7 +259,7 @@
*
* Panel factorization
*
- CALL ZLAHEF_AASEN( UPLO, 2-K1, N-J, JB,
+ CALL ZLAHEF_AA( UPLO, 2-K1, N-J, JB,
$ A( MAX(1, J), J+1 ), LDA,
$ IPIV( J+1 ), WORK, N, WORK( N*NB+1 ),
$ IINFO )
@@ -383,7 +383,7 @@
*
* Panel factorization
*
- CALL ZLAHEF_AASEN( UPLO, 2-K1, N-J, JB,
+ CALL ZLAHEF_AA( UPLO, 2-K1, N-J, JB,
$ A( J+1, MAX(1, J) ), LDA,
$ IPIV( J+1 ), WORK, N, WORK( N*NB+1 ), IINFO)
IF( (IINFO.GT.0) .AND. (INFO.EQ.0) ) THEN
@@ -478,6 +478,6 @@
20 CONTINUE
RETURN
*
-* End of ZHETRF_AASEN
+* End of ZHETRF_AA
*
END
@@ -6,19 +6,19 @@
* ===========
*
-* SUBROUTINE ZHETRF_AASEN( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
+* SUBROUTINE ZHETRF_AA( UPLO, N, A, LDA, IPIV, WORK, LWORK, INFO )
*
* .. Scalar Arguments ..
@@ -34,7 +34,7 @@
*> \verbatim
*>
-*> ZHETRF_AASEN computes the factorization of a complex hermitian matrix A
+*> ZHETRF_AA computes the factorization of a complex hermitian matrix A
*> using the Aasen's algorithm. The form of the factorization is
*>
diff --git a/SRC/zhetrs_aasen.f b/SRC/zhetrs_aa.f
index 3cad26c2..4cfdec64 100644
--- a/SRC/zhetrs_aasen.f
+++ b/SRC/zhetrs_aa.f
@@ -1,4 +1,4 @@
-*> \brief \b ZHETRS_AASEN
+*> \brief \b ZHETRS_AA
*
* =========== DOCUMENTATION ===========
*
@@ -6,19 +6,19 @@
* http://www.netlib.org/lapack/explore-html/
*
*> \htmlonly
-*> Download ZHETRS_AASEN + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/zhetrs_aasen.f">
+*> Download ZHETRS_AA + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/zhetrs_aa.f">
*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/zhetrs_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/zhetrs_aa.f">
*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/zhetrs_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/zhetrs_aa.f">
*> [TXT]</a>
*> \endhtmlonly
*
* Definition:
* ===========
*
* SUBROUTINE ZHETRS_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
* WORK, LWORK, INFO )
*
* .. Scalar Arguments ..
@@ -36,9 +36,9 @@
*>
*> \verbatim
*>
*> ZHETRS_AASEN solves a system of linear equations A*X = B with a real
*> hermitian matrix A using the factorization A = U*T*U**T or
-*> A = L*T*L**T computed by ZHETRF_AASEN.
+*> A = L*T*L**T computed by ZHETRF_AA.
*> \endverbatim
*
* Arguments:
@@ -69,7 +69,7 @@
*> \param[in,out] A
*> \verbatim
*> A is COMPLEX*16 array, dimension (LDA,N)
-*> Details of factors computed by ZHETRF_AASEN.
+*> Details of factors computed by ZHETRF_AA.
*> \endverbatim
*>
*> \param[in] LDA
@@ -81,7 +81,7 @@
*> \param[in] IPIV
*> \verbatim
*> IPIV is INTEGER array, dimension (N)
-*> Details of the interchanges as computed by ZHETRF_AASEN.
+*> Details of the interchanges as computed by ZHETRF_AA.
*> \endverbatim
*>
*> \param[in,out] B
@@ -126,7 +126,7 @@
*> \ingroup complex16HEcomputational
*
* =====================================================================
- SUBROUTINE ZHETRS_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
+ SUBROUTINE ZHETRS_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
$ WORK, LWORK, INFO )
*
* -- LAPACK computational routine (version 3.7.0) --
@@ -183,7 +183,7 @@
INFO = -10
END IF
IF( INFO.NE.0 ) THEN
- CALL XERBLA( 'ZHETRS_AASEN', -INFO )
+ CALL XERBLA( 'ZHETRS_AA', -INFO )
RETURN
ELSE IF( LQUERY ) THEN
LWKOPT = (3*N-2)
@@ -282,6 +282,6 @@
*
RETURN
*
-* End of ZHETRS_AASEN
+* End of ZHETRS_AA
*
END
@@ -6,19 +6,19 @@
* ===========
*
-* SUBROUTINE ZHETRS_AASEN( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
+* SUBROUTINE ZHETRS_AA( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
* WORK, LWORK, INFO )
*
@@ -36,9 +36,9 @@
*> \verbatim
*>
-*> ZHETRS_AASEN solves a system of linear equations A*X = B with a real
+*> ZHETRS_AA solves a system of linear equations A*X = B with a real
*> hermitian matrix A using the factorization A = U*T*U**T or
diff --git a/SRC/zlahef_aasen.f b/SRC/zlahef_aa.f
index 0503af7d..2df13146 100644
--- a/SRC/zlahef_aasen.f
+++ b/SRC/zlahef_aa.f
@@ -1,4 +1,4 @@
-*> \brief \b ZLAHEF_AASEN
+*> \brief \b ZLAHEF_AA
*
* =========== DOCUMENTATION ===========
*
@@ -6,19 +6,19 @@
* http://www.netlib.org/lapack/explore-html/
*
*> \htmlonly
-*> Download ZLAHEF_AASEN + dependencies
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/zlahef_aasen.f">
+*> Download ZLAHEF_AA + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/zlahef_aa.f">
*> [TGZ]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/zlahef_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/zlahef_aa.f">
*> [ZIP]</a>
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/zlahef_aasen.f">
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/zlahef_aa.f">
*> [TXT]</a>
*> \endhtmlonly
*
* Definition:
* ===========
*
* SUBROUTINE ZLAHEF_AASEN( UPLO, J1, M, NB, A, LDA, IPIV,
* H, LDH, WORK, INFO )
*
* .. Scalar Arguments ..
@@ -36,7 +36,7 @@
*>
*> \verbatim
*>
-*> DLATRF_AASEN factorizes a panel of a real hermitian matrix A using
+*> DLATRF_AA factorizes a panel of a real hermitian matrix A using
*> the Aasen's algorithm. The panel consists of a set of NB rows of A
*> when UPLO is U, or a set of NB columns when UPLO is L.
*>
@@ -66,7 +66,7 @@
*> J1 is INTEGER
*> The location of the first row, or column, of the panel
*> within the submatrix of A, passed to this routine, e.g.,
-*> when called by ZHETRF_AASEN, for the first panel, J1 is 1,
+*> when called by ZHETRF_AA, for the first panel, J1 is 1,
*> while for the remaining panels, J1 is 2.
*> \endverbatim
*>
@@ -151,7 +151,7 @@
*> \ingroup complex16HEcomputational
*
* =====================================================================
- SUBROUTINE ZLAHEF_AASEN( UPLO, J1, M, NB, A, LDA, IPIV,
+ SUBROUTINE ZLAHEF_AA( UPLO, J1, M, NB, A, LDA, IPIV,
$ H, LDH, WORK, INFO )
*
* -- LAPACK computational routine (version 3.7.0) --
@@ -211,7 +211,7 @@
$ GO TO 20
*
* K is the column to be factorized
-* when being called from ZHETRF_AASEN,
+* when being called from ZHETRF_AA,
* > for the first block column, J1 is 1, hence J1+J-1 is J,
* > for the rest of the columns, J1 is 2, and J1+J-1 is J+1,
*
@@ -365,7 +365,7 @@
$ GO TO 40
*
* K is the column to be factorized
-* when being called from ZHETRF_AASEN,
+* when being called from ZHETRF_AA,
* > for the first block column, J1 is 1, hence J1+J-1 is J,
* > for the rest of the columns, J1 is 2, and J1+J-1 is J+1,
*
@@ -508,6 +508,6 @@
END IF
RETURN
*
-* End of ZLAHEF_AASEN
+* End of ZLAHEF_AA
*
END
@@ -6,19 +6,19 @@
* ===========
*
-* SUBROUTINE ZLAHEF_AASEN( UPLO, J1, M, NB, A, LDA, IPIV,
+* SUBROUTINE ZLAHEF_AA( UPLO, J1, M, NB, A, LDA, IPIV,
* H, LDH, WORK, INFO )
*